<?php
namespace Teknisa\PLA\Modules\Parametros\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;


class Pla05000CombinacaoPratosController extends \Teknisa\GER\Controllers\TeknisaCrud {
	protected $parameterBagColumns;
	protected $crudService;
	protected $dataSourceManager;
	protected $environment;
	protected $parameterBag;
	protected $novoCodigo;
	protected $combinacaoPratosService;
	
	public function __construct($crudService, $parameterBag, $dataSourceManager, $environment, $entityManager, $novoCodigo, $combinacaoPratosService){
		$this->crudService 	                            = $crudService;
	    $this->parameterBag                             = $parameterBag;
		$this->dataSourceManager                        = $dataSourceManager;
		$this->environment 			                    = $environment;
		$this->entityManager                            = $entityManager;
		$this->novoCodigo                               = $novoCodigo;
		$this->Pla05000CombinacaoPratosService          = $combinacaoPratosService;                                         

		parent::__construct($crudService, $parameterBag);
	}
	
	
	
	public function savePai(DTO\Request\Row $request, DTO\Response $response) {
		try{
            $row = $request->getRow();
			$data = $this->getCombGrupoPrato($row);
			if(empty($data)){
				$nrCombGrupoTpPrat = $this->novoCodigo->getCodeByTableName("COMBGRUPOTPPRAT", $this->environment->getNrOrg());
				$row['NRCOMBGRUPOTPPRAT'] = $nrCombGrupoTpPrat;
	            $this->Pla05000CombinacaoPratosService->savePai($row);
	            $this->saveFilho($row, $response);
	            $response->addNotification(new Notification("Dados salvos com sucesso"), Notification::TYPE_SUCCESS);
			}else {
				$response->setError(new Error("registroExiste", 1));
			}
        }catch(\Excepition $e){
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
	}
	
	public function saveFilho($row, $response) {
		try{
			$nrItCombGrupoTpPrat = $this->novoCodigo->getCodeByTableName("ITCOMBGRUPOTPPRAT", $this->environment->getNrOrg());
			$row['NRITCOMBGRUPOTPPRAT'] = $nrItCombGrupoTpPrat;
			$this->Pla05000CombinacaoPratosService->saveFilho($row);
        }catch(\Excepition $e){
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
	}
	
	public function saveFilhoFrontEnd(DTO\Request\Row $request, DTO\Response $response) {
		try{
			$row = $request->getRow();
			foreach ($row['NMPRATOFILHO'] as $rowFilho) {
				if(!isset($row['NRITCOMBGRUPOTPPRAT']) || !$row['NRITCOMBGRUPOTPPRAT']){
					$row['NRITCOMBGRUPOTPPRAT'] = $this->novoCodigo->getCodeByTableName("ITCOMBGRUPOTPPRAT", $this->environment->getNrOrg());
				}
				
				$rowSave = array(
					"NRITCOMBGRUPOTPPRAT" => $row['NRITCOMBGRUPOTPPRAT'],
					"NRCOMBGRUPOTPPRAT"   => $row['NRCOMBGRUPOTPPRAT'],
					"CDGRTIPOPR"          => $row['CDGRTIPOPRFILHO'],
					"CDPRATO"             => $rowFilho['CDPRATO'],
					"IDCOMBINACAO"        => $row['IDCOMBINACAO'], 
					"CDFILAUXPRAT"        => $rowFilho['CDFILAUXPRAT'],
					"PERCENTREDUCAO"      => $row['IDCOMBINACAO'] == 'OBRIGATORIO' ? $row['PERCENTREDUCAO'] : null,
					"__is_new"            => $row['__is_new']
				);
				$dataSet = new DataSet('itcombgrupotpprat', array($rowSave));
	            $request = new DTO\Request\DataSet($dataSet, "", "", "");
	            $rowsToSave = $this->crudService->getRowsToSave($request, 'itcombgrupotpprat');
	            $dataSet = new DataSet('itcombgrupotpprat', $rowsToSave);
        		$this->dataSourceManager->persist($dataSet);
        		
				$response->addNotification(new Notification("Dados salvos com sucesso"), Notification::TYPE_SUCCESS);
			}
		}catch(\Excepition $e){
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
	}

	private function getCombGrupoPrato($row) {
        $conditions = array(
            array(
                "columnName" => "CDGRTIPOPR",
                "operator" => "=",
                "value" => $row['CDGRTIPOPRPAI']
            ),
            array(
                "columnName" => "CDFILAUXPRAT",
                "operator" => "=",
                "value" => $row['CDFILAUXPRATPAI']
            ),
            array(
                "columnName" => "CDFILIAL",
                "operator" => "=",
                "value" => $row['CDFILIAL']
            ),
            array(
                "columnName" => "CDPRATO",
                "operator" => "=",
                "value" => $row['CDPRATOPAI']
            )
        );
        return $this->crudService->getFilteredDataSet("pla05000_combgrupotpprat", $conditions)->getRows();
    }
    
    private function getItCombGrupoPrato($row) {
        $conditions = array(
            array(
                "columnName" => "CDGRTIPOPR",
                "operator" => "=",
                "value" => $row['CDGRTIPOPR']
            ),
            array(
                "columnName" => "CDFILAUXPRAT",
                "operator" => "=",
                "value" => $row['CDFILAUXPRAT']
            ),
            array(
                "columnName" => "NRCOMBGRUPOTPPRAT",
                "operator" => "=",
                "value" => $row['NRCOMBGRUPOTPPRAT']
            ),
            array(
                "columnName" => "CDPRATO",
                "operator" => "=",
                "value" => $row['CDPRATO']
            )
        );
        return $this->crudService->getFilteredDataSet("pla05000_itcombgrupotpprat", $conditions)->getRows();
    }
}
